==> confluence-create-content-plugin-7.0.0-sources.jar: com/atlassian/confluence/plugins/createcontent/services/model/CreateBlueprintPageRequest.java <==
package com.atlassian.confluence.plugins.createcontent.services.model;

import com.atlassian.confluence.pages.Page;
import com.atlassian.confluence.plugins.createcontent.impl.ContentBlueprint;
import com.atlassian.confluence.plugins.createcontent.impl.ContentTemplateRef;
import com.atlassian.confluence.spaces.Space;
import com.atlassian.confluence.user.ConfluenceUser;

import java.util.Map;

/**
 * An Entity that represents the information needed to create a page from a Blueprint.
 */
public class CreateBlueprintPageRequest {
    private final Space space;
    private final String title;
    private final String viewPermissionsUsers;
    private final Page parentPage;
    private final Map<String, Object> context;
    private final ContentTemplateRef contentTemplateRef;
    private final ConfluenceUser creator;
    private final ContentBlueprint contentBlueprint;

    public CreateBlueprintPageRequest(Space space, String title, String viewPermissionsUsers, Page parentPage,
                                      Map<String, Object> context, ContentTemplateRef contentTemplateRef, ConfluenceUser creator,
                                      ContentBlueprint contentBlueprint) {
        this.space = space;
        this.title = title;
        this.viewPermissionsUsers = viewPermissionsUsers;
        this.parentPage = parentPage;
        this.context = context;
        this.contentTemplateRef = contentTemplateRef;
        this.creator = creator;
        this.contentBlueprint = contentBlueprint;
    }

    public Page getParentPage() {
        return parentPage;
    }

    public Map<String, Object> getContext() {
        return context;
    }

    public String getTitle() {
        return title;
    }

    public String getViewPermissionsUsers() {
        return viewPermissionsUsers;
    }

    public ContentTemplateRef getContentTemplateRef() {
        return contentTemplateRef;
    }

    public Space getSpace() {
        return space;
    }

    public ConfluenceUser getCreator() {
        return creator;
    }

    public ContentBlueprint getContentBlueprint() {
        return contentBlueprint;
    }
}

==> confluence-create-content-plugin-12.1.1-sources.jar: com/atlassian/confluence/plugins/createcontent/services/model/CreateBlueprintPageRequest.java <==
package com.atlassian.confluence.plugins.createcontent.services.model;

import com.atlassian.confluence.pages.Page;
import com.atlassian.confluence.plugins.createcontent.impl.ContentBlueprint;
import com.atlassian.confluence.plugins.createcontent.impl.ContentTemplateRef;
import com.atlassian.confluence.spaces.Space;
import com.atlassian.confluence.user.ConfluenceUser;

import java.util.Map;

/**
 * A partially fleshed out {@link CreateBlueprintPageEntity} with a {@link Space} and {@link Page} instead of Strings.
 * It contains the information needed to create a page from a Blueprint.
 */
public class CreateBlueprintPageRequest {
    private final Space space;
    private final String title;
    private final String viewPermissionsUsers;
    private final Page parentPage;
    private final Map<String, Object> context;
    private final ContentTemplateRef contentTemplateRef;
    private final ConfluenceUser creator;
    private final ContentBlueprint contentBlueprint;

    public CreateBlueprintPageRequest(Space space, String title, String viewPermissionsUsers, Page parentPage,
                                      Map<String, Object> context, ContentTemplateRef contentTemplateRef, ConfluenceUser creator,
                                      ContentBlueprint contentBlueprint) {
        this.space = space;
        this.title = title;
        this.viewPermissionsUsers = viewPermissionsUsers;
        this.parentPage = parentPage;
        this.context = context;
        this.contentTemplateRef = contentTemplateRef;
        this.creator = creator;
        this.contentBlueprint = contentBlueprint;
    }

    public Page getParentPage() {
        return parentPage;
    }

    public Map<String, Object> getContext() {
        return context;
    }

    public String getTitle() {
        return title;
    }

    public String getViewPermissionsUsers() {
        return viewPermissionsUsers;
    }

    public ContentTemplateRef getContentTemplateRef() {
        return contentTemplateRef;
    }

    public Space getSpace() {
        return space;
    }

    public ConfluenceUser getCreator() {
        return creator;
    }

    public ContentBlueprint getContentBlueprint() {
        return contentBlueprint;
    }
}
